@@ -2,6 +2,7 @@
 
 from .constants import Protocol, Packets
 from . import _tool, _packet
+from requests import get
 
 __version__ = []
 
@@ -11,11 +12,8 @@ def isOnline(Address: str):
     # IMPORT
     from scapy.layers.inet import IP
 
-    # CREATING PACKET & RUN & RETURN
-    try:
-        IP(dst = Address)
+    # RUN & RETURN
+    if get("example.org").status_code == 200:
         return True
-    except:
+    else
         return False
-    
-
